Object Detection {#tutorial_js_table_of_contents_objdetect}
================

-   @subpage tutorial_js_face_detection

    Face detection
    using haar-cascades

-   @subpage tutorial_js_face_detection_camera

    Face Detection in Video Capture
